@@ -9,6 +9,7 @@ from typing import Optional, List, Sequence
 
 import AnyQt
 from AnyQt.QtWidgets import QApplication
+from AnyQt.QtGui import QPixmapCache
 from AnyQt.QtCore import (
     Qt, QUrl, QEvent, QSettings, QLibraryInfo, pyqtSignal as Signal,
     QT_VERSION_INFO
@@ -109,6 +110,7 @@ else:
 
 class CanvasApplication(QApplication):
     fileOpenRequest = Signal(QUrl)
+    applicationPaletteChanged = Signal()
 
     __args = None
 
@@ -159,6 +161,8 @@ class CanvasApplication(QApplication):
                 self.fileOpenRequest.emit(event.url())
         elif event.type() == QEvent.PolishRequest:
             self.configureStyle()
+        elif event.type() == QEvent.Type.ApplicationPaletteChange:
+            self.applicationPaletteChanged.emit()
         return super().event(event)
 
     def exec(self) -> int:
@@ -231,6 +235,7 @@ class CanvasApplication(QApplication):
         if theme and theme in styles.colorthemes:
             palette = styles.colorthemes[theme]()
             QApplication.setPalette(palette)
+        QPixmapCache.setCacheLimit(64 * (2 ** 10))
 
 
 __restart_command: Optional[List[str]] = None
