@@ -35,11 +35,14 @@ from AnyQt.QtCore import (
 from AnyQt.QtCore import pyqtSignal as Signal, pyqtProperty as Property
 
 from .usagestatistics import UsageStatistics
+from .. import styles
 from ..gui.framelesswindow import FramelessWindow
 from ..gui.lineedit import LineEdit
+from ..gui.iconengine import StyledIconEngine
 from ..gui.tooltree import ToolTree, FlattenedTreeItemModel
 from ..gui.utils import StyledWidget_paintEvent, innerGlowBackgroundPixmap, innerShadowPixmap
 from ..registry.qt import QtWidgetRegistry
+from ..registry.utils import search_filter_query_helper
 
 from ..resources import icon_loader, load_styled_svg_icon
 
@@ -90,7 +93,8 @@ class _MenuItemDelegate(QStyledItemDelegate):
         decRect = QRectF(decTl, decBr)
 
         # draw icon pixmap
-        dec.paint(painter, decRect.toAlignedRect())
+        with StyledIconEngine.setOverridePalette(styles.breeze_light()):
+            dec.paint(painter, decRect.toAlignedRect())
 
         # draw display
         rect = QRect(opt.rect)
@@ -485,19 +489,7 @@ class SortFilterProxyModel(QSortFilterProxyModel):
         if description is None:
             return False
 
-        name = description.name.lower()
-        keywords = [k.lower() for k in description.keywords]
-        for k in keywords[:]:
-            if '-' in k:
-                keywords.append(k.replace('-', ''))
-                keywords.append(k.replace('-', ' '))
-
-        query = self.__query
-        # match name and keywords
-        accepted = (not query or
-                    query in name or
-                    query in name.replace(' ', '') or
-                    any(k.startswith(query) for k in keywords))
+        accepted = search_filter_query_helper(description, self.__query)
 
         # if matches query, apply filter function (compatibility with paired widget)
         if accepted and self.__filterFunc is not None:
@@ -697,15 +689,16 @@ class TabButton(QToolButton):
         self.initStyleOption(opt)
         if self.__showMenuIndicator and self.isChecked():
             opt.features |= QStyleOptionToolButton.HasMenu
-        if self.__flat:
-            # Use default widget background/border styling.
-            StyledWidget_paintEvent(self, event)
+        with StyledIconEngine.setOverridePalette(styles.breeze_light()):
+            if self.__flat:
+                # Use default widget background/border styling.
+                StyledWidget_paintEvent(self, event)
 
-            p = QStylePainter(self)
-            p.drawControl(QStyle.CE_ToolButtonLabel, opt)
-        else:
-            p = QStylePainter(self)
-            p.drawComplexControl(QStyle.CC_ToolButton, opt)
+                p = QStylePainter(self)
+                p.drawControl(QStyle.CE_ToolButtonLabel, opt)
+            else:
+                p = QStylePainter(self)
+                p.drawComplexControl(QStyle.CC_ToolButton, opt)
 
         # if checked, no shadow
         if self.isChecked():
